@@ -1,5 +1,5 @@
-# -*- coding: utf-8 -*-
 import itertools as it
+import os
 from os.path import join
 import ubelt as ub
 import sys
@@ -11,17 +11,17 @@ def test_import_modpath_basic():
     assert 'testmod' not in sys.modules
 
     with ub.TempDir() as temp:
-        modpath = join(temp.dpath, 'testmod.py')
+        modpath = ub.Path(temp.dpath) / 'testmod.py'
         text = ub.codeblock(
             '''
             a = 'value'
             ''')
-        ub.writeto(modpath, text)
+        modpath.write_text(text)
         assert temp.dpath not in sys.path
         module = ub.import_module_from_path(modpath)
         assert temp.dpath not in sys.path, 'pythonpath should remain clean'
         assert module.a == 'value'
-        assert module.__file__ == modpath
+        assert module.__file__ == os.fspath(modpath)
         assert module.__name__ == 'testmod'
         assert 'testmod' in sys.modules
 
@@ -32,28 +32,28 @@ def test_import_modpath_package():
     temp = ub.TempDir().start()
     # with ub.TempDir() as temp:
     if True:
-        dpath = temp.dpath
+        dpath = ub.Path(temp.dpath)
 
-        # Create a dummy package heirachy
-        root = ub.ensuredir((dpath, '_tmproot373'))
-        sub1 = ub.ensuredir((root, 'sub1'))
-        sub2 = ub.ensuredir((sub1, 'sub2'))
+        # Create a dummy package hierarchy
+        root = (dpath / '_tmproot373').ensuredir()
+        sub1 = (root / 'sub1').ensuredir()
+        sub2 = (sub1 / 'sub2').ensuredir()
 
-        ub.touch(join(root, '__init__.py'))
-        ub.touch(join(sub1, '__init__.py'))
-        ub.touch(join(sub2, '__init__.py'))
+        (root / '__init__.py').touch()
+        (sub1 / '__init__.py').touch()
+        (sub2 / '__init__.py').touch()
 
-        modpath = join(sub2, 'testmod.py')
+        modpath = sub2 / 'testmod.py'
         text = ub.codeblock(
             '''
             a = 'value'
             ''')
-        ub.writeto(modpath, text)
+        modpath.write_text(text)
         assert temp.dpath not in sys.path
         module = ub.import_module_from_path(modpath)
         assert temp.dpath not in sys.path, 'pythonpath should remain clean'
         assert module.a == 'value'
-        assert module.__file__ == modpath
+        assert module.__file__ == os.fspath(modpath)
         assert module.__name__ == '_tmproot373.sub1.sub2.testmod'
         assert '_tmproot373.sub1.sub2.testmod' in sys.modules
         assert '_tmproot373.sub1.sub2' in sys.modules
@@ -118,7 +118,7 @@ def test_modname_to_modpath_package():
     with ub.TempDir() as temp:
         dpath = temp.dpath
 
-        # Create a dummy package heirachy
+        # Create a dummy package hierarchy
         root = ub.ensuredir((dpath, '_tmproot927'))
         sub1 = ub.ensuredir((root, 'sub1'))
         sub2 = ub.ensuredir((sub1, 'sub2'))
@@ -147,7 +147,7 @@ def test_modname_to_modpath_package():
             assert _static_modname_to_modpath('_tmproot927.sub1.bad1.b1') is None
             assert _static_modname_to_modpath('_tmproot927.bad1') is None
 
-            # package modules are accessable by the full path
+            # package modules are accessible by the full path
             assert root == _static_modname_to_modpath('_tmproot927')
             assert sub1 == _static_modname_to_modpath('_tmproot927.sub1')
             assert sub2 == _static_modname_to_modpath('_tmproot927.sub1.sub2')
@@ -301,7 +301,7 @@ def test_package_submodules():
     with ub.TempDir() as temp:
         dpath = temp.dpath
 
-        # Create a dummy package heirachy
+        # Create a dummy package hierarchy
         root = ub.ensuredir((dpath, '_tmproot927'))
         sub1 = ub.ensuredir((root, 'sub1'))
         sub2 = ub.ensuredir((sub1, 'sub2'))
@@ -361,7 +361,7 @@ def test_modpath_to_modname():
     with ub.TempDir() as temp:
         dpath = temp.dpath
 
-        # Create a dummy package heirachy
+        # Create a dummy package hierarchy
         root = ub.ensuredir((dpath, '_tmproot927'))
         sub1 = ub.ensuredir((root, 'sub1'))
         sub2 = ub.ensuredir((sub1, 'sub2'))
@@ -427,7 +427,7 @@ def test_modpath_to_modname():
             assert ub.modpath_to_modname(root_main, hide_main=True, hide_init=False) == '_tmproot927'
             assert ub.modpath_to_modname(sub2_main, hide_main=True, hide_init=False) == '_tmproot927.sub1.sub2'
 
-            # Non-existant / invalid modules should always be None
+            # Non-existent / invalid modules should always be None
             for a, b in it.product([True, False], [True, False]):
                 with pytest.raises(ValueError):
                     ub.modpath_to_modname(join(sub1, '__main__.py'), hide_main=a, hide_init=b)
