@@ -30,7 +30,7 @@ Example:
 __all__ = ['NoParam']
 
 
-class _NoParamType(object):
+class NoParamType(object):
     r"""
     Class used to define :data:`NoParam`, a sentinel that acts like None when
     None might be a valid value. The value of :data:`NoParam` is robust to
@@ -42,17 +42,68 @@ class _NoParamType(object):
     References:
         .. [SO_41048643]: http://stackoverflow.com/questions/41048643/a-second-none
 
+    Example:
+        >>> # Use case
+        >>> # Imagine you need a function with a default argument, but you need to
+        >>> # distinguish between cases where the user called it without specifying
+        >>> # a default, versus the user specifying None. For instance, imagine you
+        >>> # are writing the code for a dictionary ``get(key, default)``.
+        >>> #
+        >>> # You want the user to distinguish between the user calling it with
+        >>> # None and the user not calling it at all.
+        >>> #
+        >>> # So you can't write it like this because you can't distinguish between
+        >>> # the user passing default as None, or not passing a default at all.
+        >>> def get(self, key, default=None):
+        >>>     if default is None:
+        >>>         ...  # What do?!
+        >>> #
+        >>> # You could write it like this, which is long and annoying
+        >>> def get(self, key, *args, **kw):
+        >>>     try:
+        >>>         return self[key]
+        >>>     except KeyError as ke:
+        >>>         if len(args) > 0:
+        >>>             return args[0]
+        >>>         elif 'default' in kw:
+        >>>             return kw['default']
+        >>>         else:
+        >>>             raise
+        >>> #
+        >>> # Instead write it like this, which is short and nice
+        >>> from ubelt import NoParam
+        >>> def get(self, key, default=NoParam):
+        >>>     try:
+        >>>         return self[key]
+        >>>     except KeyError:
+        >>>         if default is NoParam:
+        >>>             raise
+        >>>         return default
+        >>> #
+        >>> # setup some data
+        >>> self = {}
+        >>> key = 'spam'
+        >>> #
+        >>> # If the key is not in the dictionary, raise a KeyError
+        >>> import pytest
+        >>> with pytest.raises(KeyError):
+        >>>     get(self, key)
+        >>> #
+        >>> # If the key is not in the dictionary, return ``default``
+        >>> get(self, key, None)  # with positional args
+        >>> get(self, key, default=None)  # with keyword args
+
     Example:
         >>> import ubelt as ub
         >>> from ubelt import util_const
-        >>> from ubelt.util_const import _NoParamType, NoParam
-        >>> from six.moves import cPickle as pickle
+        >>> from ubelt.util_const import NoParamType, NoParam
+        >>> import pickle
         >>> import copy
         >>> id_ = id(NoParam)
         >>> versions = {
         ... 'ub.util_const.NoParam': ub.util_const.NoParam,
         ... 'NoParam': NoParam,
-        ... '_NoParamType()': _NoParamType(),
+        ... 'NoParamType()': NoParamType(),
         ... 'ub.NoParam': ub.NoParam,
         ... 'copy': copy.copy(NoParam),
         ... 'deepcopy': copy.deepcopy(NoParam),
@@ -60,7 +111,6 @@ class _NoParamType(object):
         ... }
         >>> print(versions)
         >>> assert all(id(v) == id_ for v in versions.values())
-        >>> import six
         >>> from importlib import reload
         >>> reload(util_const)
         >>> assert id(util_const.NoParam) == id_
@@ -73,7 +123,7 @@ class _NoParamType(object):
     def __new__(cls):
         return NoParam
     def __reduce__(self):
-        return (_NoParamType, ())
+        return (NoParamType, ())
     def __copy__(self):
         return NoParam
     def __deepcopy__(self, memo):
@@ -86,8 +136,10 @@ class _NoParamType(object):
         # Ensure NoParam is Falsey
         return False
 
+# Backwards compat
+_NoParamType = NoParamType
 
-# Create the only instance of _NoParamType that should ever exist
+# Create the only instance of NoParamType that should ever exist
 try:
     # If the module is reloaded (via imp.reload), globals() will contain
     # NoParam. This skips the code that would instantiate a second object
@@ -99,4 +151,4 @@ except NameError:  # pragma: no cover
     # When the module is first loaded, globals() will not contain NoParam. A
     # NameError will be thrown, causing the first instance of NoParam to be
     # instantiated.
-    NoParam = object.__new__(_NoParamType)  # type: _NoParamType
+    NoParam = object.__new__(NoParamType)  # type: NoParamType
