@@ -38,8 +38,8 @@ The :func:`ddict` and :func:`odict` functions are alias for the commonly used
 Related Work:
     * Note that Python does support set operations on dictionary **views** [DictView]_ [Pep3106]_, but these methods can be inflexible and often leave you only with keys (and no dictionary subset operation), whereas the ubelt definition of these operations is more straightforward.
     * There are several recipes for dictionaries that support set operations [SetDictRecipe1]_ [SetDictRecipe2]_.
-    * The :moduel:`dictmap` package contains a function similar to :func:`map_values` [GHDictMap]_.
-    * The :module:`dictdiffer` package contains tools for nested difference operations [PypiDictDiffer]_.
+    * The :py:mod:`dictmap` package contains a function similar to :func:`map_values` [GHDictMap]_.
+    * The :py:mod:`dictdiffer` package contains tools for nested difference operations [PypiDictDiffer]_.
     * There are lots of other python dictionary utility libraries [PyPIAddict]_.
 
 References:
@@ -57,7 +57,6 @@ import itertools as it
 from collections import OrderedDict
 from collections import defaultdict
 # from ubelt import util_const
-from ubelt import util_list
 from ubelt.util_const import NoParam
 
 __all__ = [
@@ -196,7 +195,7 @@ def dict_hist(items, weights=None, ordered=False, labels=None):
             hashable items (usually containing duplicates)
 
         weights (Iterable[float], default=None):
-            Corresponding weights for each item.
+            Corresponding weights for each item, defaults to 1 if unspecified.
 
         ordered (bool, default=False):
             If True the result is ordered by frequency.
@@ -211,6 +210,9 @@ def dict_hist(items, weights=None, ordered=False, labels=None):
             dictionary where the keys are unique elements from ``items``, and
             the values are the number of times the item appears in ``items``.
 
+    SeeAlso:
+        :class:`collections.Counter`
+
     Example:
         >>> import ubelt as ub
         >>> items = [1, 2, 39, 900, 1232, 900, 1232, 2, 2, 2, 900]
@@ -220,15 +222,12 @@ def dict_hist(items, weights=None, ordered=False, labels=None):
 
     Example:
         >>> import ubelt as ub
+        >>> import pytest
         >>> items = [1, 2, 39, 900, 1232, 900, 1232, 2, 2, 2, 900]
         >>> hist1 = ub.dict_hist(items)
         >>> hist2 = ub.dict_hist(items, ordered=True)
-        >>> try:
+        >>> with pytest.raises(KeyError):
         >>>     hist3 = ub.dict_hist(items, labels=[])
-        >>> except KeyError:
-        >>>     pass
-        >>> else:
-        >>>     raise AssertionError('expected key error')
         >>> weights = [1, 1, 1, 0, 0, 0, 0, 1, 1, 1, 1]
         >>> hist4 = ub.dict_hist(items, weights=weights)
         >>> print(ub.repr2(hist1, nl=0))
@@ -236,15 +235,22 @@ def dict_hist(items, weights=None, ordered=False, labels=None):
         >>> print(ub.repr2(hist4, nl=0))
         {1: 1, 2: 4, 39: 1, 900: 1, 1232: 0}
     """
-    if labels is None:
-        hist_ = defaultdict(lambda: 0)
+    if weights is None and labels is None:
+        # Accumulate discrete frequency.
+        # In this special case we use an optimized stdlib routine
+        from collections import Counter
+        hist_ = Counter()
+        hist_.update(items)
     else:
-        hist_ = {k: 0 for k in labels}
-    if weights is None:
-        weights = it.repeat(1)
-    # Accumulate frequency
-    for item, weight in zip(items, weights):
-        hist_[item] += weight
+        if labels is None:
+            hist_ = defaultdict(lambda: 0)
+        else:
+            hist_ = {k: 0 for k in labels}
+        if weights is None:
+            weights = it.repeat(1)  # 2x slower than Counter
+        # Accumulate weighted frequency
+        for item, weight in zip(items, weights):
+            hist_[item] += weight
     if ordered:
         # Order by value
         getval = op.itemgetter(1)
@@ -345,6 +351,7 @@ def dict_subset(dict_, keys, default=NoParam, cls=OrderedDict):
 
     SeeAlso:
         :func:`dict_isect` - similar functionality, but ignores missing keys
+        ::py:meth:`UDict.subdict` - object oriented version of this function
 
     Example:
         >>> import ubelt as ub
@@ -354,6 +361,7 @@ def dict_subset(dict_, keys, default=NoParam, cls=OrderedDict):
         >>> print(ub.repr2(subdict_, nl=0))
         {'K': 3, 'dcvs_clip_max': 0.2}
     """
+    from ubelt import util_list
     keys = list(keys)
     items = util_list.take(dict_, keys, default)
     subdict_ = cls(list(zip(keys, items)))
@@ -388,6 +396,7 @@ def dict_union(*args):
         :func:`collections.ChainMap` - a standard python builtin data structure
         that provides a view that treats multiple dicts as a single dict.
         `<https://docs.python.org/3/library/collections.html#chainmap-objects>`_
+        ::py:meth:`UDict.union` - object oriented version of this function
 
     Example:
         >>> import ubelt as ub
@@ -424,9 +433,8 @@ def dict_diff(*args):
         Dict[KT, VT] | OrderedDict[KT, VT] :
             OrderedDict if the first argument is an OrderedDict, otherwise dict
 
-    TODO:
-        - [ ] Add inplace keyword argument, which modifies the first dictionary
-          inplace.
+    SeeAlso:
+        ::py:meth:`UDict.difference` - object oriented version of this function
 
     Example:
         >>> import ubelt as ub
@@ -467,6 +475,9 @@ def dict_isect(*args):
         Dict[KT, VT] | OrderedDict[KT, VT] :
             OrderedDict if the first argument is an OrderedDict, otherwise dict
 
+    SeeAlso:
+        ::py:meth:`UDict.intersection` - object oriented version of this function
+
     Note:
         This function can be used as an alternative to :func:`dict_subset`
         where any key not in the dictionary is ignored. See the following
@@ -509,11 +520,14 @@ def map_values(func, dict_, cls=None):
             if unspecified will be dict or OrderedDict. This behavior may
             change.
 
+    SeeAlso:
+        ::py:meth:`UDict.map_values` - object oriented version of this function
+
     Returns:
         Dict[KT, T]: transformed dictionary
 
     Notes:
-        Similar to :module:`dictmap.dict_map`
+        Similar to :py:mod:`dictmap.dict_map`
 
     Example:
         >>> import ubelt as ub
@@ -555,6 +569,9 @@ def map_keys(func, dict_, cls=None):
             if unspecified will be dict or OrderedDict. This behavior may
             change.
 
+    SeeAlso:
+        ::py:meth:`UDict.map_keys` - object oriented version of this function
+
     Returns:
         Dict[T, VT]: transformed dictionary
 
@@ -602,6 +619,9 @@ def sorted_values(dict_, key=None, reverse=False, cls=OrderedDict):
 
         cls (type): specifies the dict return type
 
+    SeeAlso:
+        ::py:meth:`UDict.sorted_values` - object oriented version of this function
+
     Returns:
         OrderedDict[KT, VT]: new dictionary where the values are ordered
 
@@ -647,6 +667,9 @@ def sorted_keys(dict_, key=None, reverse=False, cls=OrderedDict):
 
         cls (type): specifies the dict return type
 
+    SeeAlso:
+        ::py:meth:`UDict.sorted_keys` - object oriented version of this function
+
     Returns:
         OrderedDict[KT, VT]: new dictionary where the keys are ordered
 
@@ -686,6 +709,9 @@ def invert_dict(dict_, unique_vals=True, cls=None):
             if unspecified will be dict or OrderedDict. This behavior may
             change.
 
+    SeeAlso:
+        ::py:meth:`UDict.invert` - object oriented version of this function
+
     Returns:
         Dict[VT, KT] | Dict[VT, Set[KT]]:
             the inverted dictionary
@@ -1755,7 +1781,7 @@ class UDict(SetDict):
         Args:
             self (Dict): a dictionary or the implicit instance
 
-            default (T | NoParamType): default item to return if the iterable is empty,
+            default (KT | NoParamType): default item to return if the iterable is empty,
                 otherwise a StopIteration error is raised
 
         Returns:
@@ -1774,7 +1800,7 @@ class UDict(SetDict):
 
         Args:
             self (Dict[KT, VT]): a dictionary or the implicit instance
-            default (T | NoParamType): default item to return if the iterable is empty,
+            default (VT | NoParamType): default item to return if the iterable is empty,
                 otherwise a StopIteration error is raised
 
         Returns:
@@ -1847,20 +1873,5 @@ class AutoDict(UDict):
 
 
 # DEPRECATED. This is no longer needed. AutoDict is always ordered
-
-if sys.version_info[0:2] <= (3, 6):  # nocover
-    AutoOrderedDict = AutoDict
-else:  # nocover
-    AutoOrderedDict = AutoDict
-    # def __getattr__(key):
-    #     if key == 'AutoOrderedDict':
-    #         import ubelt as ub
-    #         ub.schedule_deprecation(
-    #             modname='ubelt', name='AutoOrderedDict', type='class',
-    #             migration='use AutoDict instead',
-    #             deprecate='1.2.0', error='2.0.0', remove='2.1.0')
-    #         return AutoDict
-    #     else:
-    #         raise AttributeError(key)
-
+AutoOrderedDict = AutoDict
 udict = UDict
