@@ -72,7 +72,7 @@ class PythonPathContext(object):
         >>>     self.__exit__(None, None, None)
     """
     def __init__(self, dpath, index=0):
-        self.dpath = dpath
+        self.dpath = os.fspath(dpath)
         self.index = index
 
     def __enter__(self):
@@ -406,12 +406,26 @@ def _syspath_modname_to_modpath(modname, sys_path=None, exclude=None):
 
     Example:
         >>> # test what happens when the module is not visible in the path
+        >>> from ubelt.util_import import *  # NOQA
+        >>> from ubelt.util_import import _syspath_modname_to_modpath
         >>> modname = 'xdoctest.static_analysis'
         >>> modpath = _syspath_modname_to_modpath(modname)
         >>> exclude = [split_modpath(modpath)[0]]
         >>> found = _syspath_modname_to_modpath(modname, exclude=exclude)
-        >>> # this only works if installed in dev mode, pypi fails
-        >>> assert found is None, 'should not have found {} because we excluded'.format(found, exclude)
+        >>> if found is not None:
+        >>>     # Note: the basic form of this test may fail if there are
+        >>>     # multiple versions of the package installed. Try and fix that.
+        >>>     other = split_modpath(found)[0]
+        >>>     assert other not in exclude
+        >>>     exclude.append(other)
+        >>>     found = _syspath_modname_to_modpath(modname, exclude=exclude)
+        >>> if found is not None:
+        >>>     raise AssertionError(
+        >>>         'should not have found {}.'.format(found) +
+        >>>         ' because we excluded: {}.'.format(exclude) +
+        >>>         ' cwd={} '.format(os.getcwd()) +
+        >>>         ' sys.path={} '.format(sys.path)
+        >>>     )
     """
     import glob
 
@@ -470,6 +484,10 @@ def _syspath_modname_to_modpath(modname, sys_path=None, exclude=None):
 
     _egglink_fname1 = _pkg_name + '.egg-link'
     _egglink_fname2 = _pkg_name_hypen + '.egg-link'
+    # FIXME! suffixed modules will clobber break!
+    # Currently mitigating this by looping over all possible matches,
+    # but it would be nice to ensure we are not matching suffixes.
+    # however, we should probably match and handle different versions.
     _editable_fname_pth_pat = '__editable__.' + _pkg_name + '-*.pth'
     _editable_fname_finder_py_pat = '__editable___' + _pkg_name + '_*finder.py'
 
@@ -489,30 +507,43 @@ def _syspath_modname_to_modpath(modname, sys_path=None, exclude=None):
         # basic pth will be used for "simple" structures (which means has a
         # src/modname folder).
         new_editable_finder_paths = sorted(glob.glob(join(dpath, _editable_fname_finder_py_pat)))
-        if new_editable_finder_paths:
+        if new_editable_finder_paths:  # nocover
             # This makes some assumptions, which may not hold in general
             # We may need to fallback entirely on pkgutil, which would
             # ultimately be good. Hopefully the new standards mean it does not
             # break with pytest anymore? Nope, pytest still doesn't work right
             # with it.
-            finder_fpath = new_editable_finder_paths[-1]
-            mapping = _static_parse('MAPPING', finder_fpath)
-            target = dirname(mapping[_pkg_name])
-            modpath = check_dpath(target)
-            if modpath:  # pragma: nobranch
-                found_modpath = modpath
+            for finder_fpath in new_editable_finder_paths:
+                mapping = _static_parse('MAPPING', finder_fpath)
+                try:
+                    target = dirname(mapping[_pkg_name])
+                except KeyError:
+                    ...
+                else:
+                    if not exclude or normalize(target) not in real_exclude:  # pragma: nobranch
+                        modpath = check_dpath(target)
+                        if modpath:  # pragma: nobranch
+                            found_modpath = modpath
+                            break
+            if found_modpath is not None:
                 break
 
         # If a finder does not exist, then the __editable__ pth file might hold
         # the path itself. Check for that.
         new_editable_pth_paths = sorted(glob.glob(join(dpath, _editable_fname_pth_pat)))
-        if new_editable_pth_paths:
+        if new_editable_pth_paths:  # nocover
+            # Disable coverage because the test that covers this is too slow.
+            # It can be made faster, re-enable when that lands.
             import pathlib
-            editable_pth = pathlib.Path(new_editable_pth_paths[-1])
-            target = editable_pth.read_text().strip().split('\n')[-1]
-            modpath = check_dpath(target)
-            if modpath:  # pragma: nobranch
-                found_modpath = modpath
+            for editable_pth in new_editable_pth_paths:
+                editable_pth = pathlib.Path(editable_pth)
+                target = editable_pth.read_text().strip().split('\n')[-1]
+                if not exclude or normalize(target) not in real_exclude:
+                    modpath = check_dpath(target)
+                    if modpath:  # pragma: nobranch
+                        found_modpath = modpath
+                        break
+            if found_modpath is not None:
                 break
 
         # If file path checks fails, check for egg-link based modules
