@@ -25,6 +25,7 @@ import operator
 from collections import abc as collections_abc
 from itertools import zip_longest
 from ubelt import util_const
+from ubelt import util_dict
 
 __all__ = [
     'allsame', 'argmax', 'argmin', 'argsort', 'argunique', 'boolmask',
@@ -878,3 +879,89 @@ def peek(iterable, default=util_const.NoParam):
         return next(iter(iterable))
     else:
         return next(iter(iterable), default)
+
+
+# Stubs for potential future object oriented wrappers
+class IterableMixin:
+    """
+
+    """
+    unique = unique
+
+    # chunks = chunks
+    histogram = util_dict.dict_hist
+    duplicates = util_dict.find_duplicates
+    group = util_dict.group_items
+
+    def chunks(self, size=None, num=None, bordermode='none'):
+        return chunks(self, chunksize=size, nchunks=num, total=len(self), bordermode=bordermode)
+
+    # def histogram(self, weights=None, ordered=False, labels=None):
+    #     util_dict.dict_hist.__doc__
+    #     return util_dict.dict_hist(self, weights=weights, ordered=ordered)
+
+    # def duplicates(self, k=2, key=None):
+    #     util_dict.find_duplicates.__doc__
+    #     return util_dict.find_duplicates(self, k=k, key=key)
+
+    # def group(self, key):
+    #     util_dict.group_items.__doc__
+    #     return util_dict.group_items(self, key=key)
+
+
+class OrderedIterableMixin(IterableMixin):
+    compress = compress
+    argunique = argunique
+    window = iter_window
+
+
+class UList(list, OrderedIterableMixin):
+    """
+    An extended list class that features additional helper methods.
+
+    Example:
+        >>> from ubelt.util_list import UList
+        >>> self = UList()
+        >>> self.append(1)
+        >>> self += UList([1, 2, 3])
+        >>> self += UList([5, 7])
+        >>> #
+        >>> print(f'unique: {list(self.unique())}')
+        >>> print(f'argunique: {list(self.argunique())}')
+        >>> #
+        >>> print(f'chunks: {list(self.chunks(num=2))}')
+        >>> print(f'chunks: {list(self.chunks(size=2))}')
+        >>> #
+        >>> print(f'window: {list(self.window(3))}')
+        >>> #
+        >>> print(f'take: {list(self.take([0, 2, 3]))}')
+        >>> print(f'compress: {list(self.compress([0, 1, 0, 1]))}')
+        >>> #
+        >>> print(f'argsort: {self.argsort()}')
+        >>> print(f'argmax: {self.argmax()}')
+        >>> print(f'argmin: {self.argmin()}')
+        >>> print(f'flatten: {list(UList([self, [2, 3, 3]]).flatten())}')
+        >>> print(f'allsame: {self.allsame()}')
+        >>> print(f'peek: {self.peek()}')
+        >>> print(f'histogram: {self.histogram()}')
+        >>> print(f'group: {self.group(key=lambda x: x % 2)}')
+        >>> print(f'duplicates: {self.duplicates()}')
+    """
+    peek = peek
+    take = take
+
+    flatten = flatten
+
+    allsame = allsame
+
+    argsort = argsort
+    argmax = argmax
+    argmin = argmin
+
+
+# class USet(set, IterableMixin):
+#     ...
+
+
+# class Set(set, IterableMixin):
+#     ...
