@@ -1,5 +1,15 @@
 """
-Functions for working with filesystem paths.
+Path and filesystem utilities.
+
+The :class:`Path` object is an extension of :class:`pathlib.Path` that contains
+extra convenience methods corresponding to the extra functional methods in this
+module. (New in 0.11.0). See the class documentation for more details.
+
+This module also defines functional path-related utilities, but moving forward
+users should prefer using :class:`Path` over standalone functional methods. The
+functions methods will still be available for the forseable future, but their
+functionality is made redundant by :class:`Path`. For completeness these
+functions are listed
 
 The :func:`expandpath` function expands the tilde to $HOME and environment
 variables to their values.
@@ -15,9 +25,9 @@ the operating system.
 
 The :func:`ensuredir` function operates like ``mkdir -p`` in unix.
 
-The :class:`Path` object is an extension of :class:`pathlib.Path` that contains
-extra convenience methods corresponding to the extra functional methods in this
-module.
+Note:
+    In the future the part of this module that defines Path may be renamed to
+    util_pathlib.
 """
 from os.path import (
     dirname, exists, expanduser, expandvars, join, normpath, split, splitext,
@@ -26,6 +36,7 @@ import os
 import sys
 from ubelt import util_io
 import pathlib
+import warnings
 
 
 __all__ = [
@@ -169,10 +180,18 @@ def userhome(username=None):
 
     Example:
         >>> from ubelt.util_path import *  # NOQA
+        >>> import ubelt as ub
         >>> import getpass
         >>> username = getpass.getuser()
-        >>> assert userhome() == expanduser('~')
-        >>> assert userhome(username) == expanduser('~')
+        >>> userhome_target = expanduser('~')
+        >>> userhome_got1 = ub.userhome()
+        >>> userhome_got2 = ub.userhome(username)
+        >>> print(f'username={username}')
+        >>> print(f'userhome_got1={userhome_got1}')
+        >>> print(f'userhome_got2={userhome_got2}')
+        >>> print(f'userhome_target={userhome_target}')
+        >>> assert userhome_got1 == userhome_target
+        >>> assert userhome_got2 == userhome_target
     """
     if username is None:
         # get home directory for the current user
@@ -345,6 +364,13 @@ class TempDir(object):
         >>> assert not exists(dpath)
     """
     def __init__(self):
+        import ubelt as ub
+        ub.schedule_deprecation(
+            modname='ubelt',
+            migration='Use tempfile instead', name='TempDir',
+            type='class', deprecate='1.2.0', error='1.4.0',
+            remove='1.5.0',
+        )
         self.dpath = None
 
     def __del__(self):
@@ -378,34 +404,59 @@ _PathBase = pathlib.WindowsPath if os.name == 'nt' else pathlib.PosixPath
 
 class Path(_PathBase):
     """
-    An extension of :class:`pathlib.Path` with extra convenience methods
+    This class extends :class:`pathlib.Path` with extra functionality and
+    convenience methods.
+
+    New methods are designed to support chaining.
+
+    In addition to new methods this class supports the addition (``+``)
+    operator via which allows for better drop-in compatibility with code using
+    existing string-based paths.
 
     Note:
-        New methods are:
-            * augment
-            * ensuredir
-            * expand
-            * expandvars
-            * ls
-            * shrinkuser
-            * walk
+        On windows this inherits from :class:`pathlib.WindowsPath`.
 
-        New classmethods are:
-            * appdir
+    New methods are
 
-        Modified methods are:
-            * touch
+        * :py:meth:`ubelt.Path.ensuredir` - Like mkdir but with easier defaults.
+
+        * :py:meth:`ubelt.Path.delete` - Previously pathlib could only remove one file at a time.
+
+        * :py:meth:`ubelt.Path.copy` - Pathlib has no similar functionality.
+
+        * :py:meth:`ubelt.Path.move` - Pathlib has no similar functionality.
+
+        * :py:meth:`ubelt.Path.augment` - Unifies and extends disparate functionality across pathlib.
+
+        * :py:meth:`ubelt.Path.expand` - Unifies existing environ and home expansion.
+
+        * :py:meth:`ubelt.Path.ls` - Like iterdir, but more interactive.
+
+        * :py:meth:`ubelt.Path.shrinkuser` - Python has no similar functionality.
+
+        * :py:meth:`ubelt.Path.walk` - Pathlib had no similar functionality.
+
+    New classmethods are
+
+        * :py:meth:`ubelt.Path.appdir` - application directories
+
+    Modified methods are
+
+        * :py:meth:`ubelt.Path.touch` - returns self to support chaining
 
     Example:
         >>> # Ubelt extends pathlib functionality
         >>> import ubelt as ub
+        >>> # Chain expansion and mkdir with cumbersome args.
         >>> dpath = ub.Path('~/.cache/ubelt/demo_path').expand().ensuredir()
         >>> fpath = dpath / 'text_file.txt'
+        >>> # Augment is concise and chainable
         >>> aug_fpath = fpath.augment(stemsuffix='.aux', ext='.jpg').touch()
         >>> aug_dpath = dpath.augment(stemsuffix='demo_path2')
         >>> assert aug_fpath.read_text() == ''
         >>> fpath.write_text('text data')
         >>> assert aug_fpath.exists()
+        >>> # Delete is akin to "rm -rf" and is also chainable.
         >>> assert not aug_fpath.delete().exists()
         >>> assert dpath.exists()
         >>> assert not dpath.delete().exists()
@@ -417,22 +468,138 @@ class Path(_PathBase):
         ~/.cache/ubelt/demo_path
         ~/.cache/ubelt/demo_path/text_file.aux.jpg
         ~/.cache/ubelt/demo_pathdemo_path2
+
+    Inherited unmodified properties from :class:`pathlib.Path` are:
+
+        * :py:data:`pathlib.PurePath.anchor`
+        * :py:data:`pathlib.PurePath.name`
+        * :py:data:`pathlib.PurePath.parts`
+        * :py:data:`pathlib.PurePath.parts`
+        * :py:data:`pathlib.PurePath.parent`
+        * :py:data:`pathlib.PurePath.parents`
+        * :py:data:`pathlib.PurePath.suffix`
+        * :py:data:`pathlib.PurePath.suffixes`
+        * :py:data:`pathlib.PurePath.stem`
+        * :py:data:`pathlib.PurePath.drive`
+        * :py:data:`pathlib.PurePath.root`
+
+    Inherited unmodified classmethods from :class:`pathlib.Path` are:
+
+        * :py:meth:`pathlib.Path.cwd`
+        * :py:meth:`pathlib.Path.home`
+
+    Inherited unmodified methods from :class:`pathlib.Path` are:
+
+        * :py:meth:`pathlib.Path.samefile`
+        * :py:meth:`pathlib.Path.iterdir`
+
+        * :py:meth:`pathlib.Path.glob`
+        * :py:meth:`pathlib.Path.rglob`
+
+        * :py:meth:`pathlib.Path.resolve`
+
+        * :py:meth:`pathlib.Path.lstat`
+        * :py:meth:`pathlib.Path.stat`
+        * :py:meth:`pathlib.Path.owner`
+        * :py:meth:`pathlib.Path.group`
+
+        * :py:meth:`pathlib.Path.open`
+        * :py:meth:`pathlib.Path.read_bytes`
+        * :py:meth:`pathlib.Path.read_text`
+        * :py:meth:`pathlib.Path.write_bytes`
+        * :py:meth:`pathlib.Path.write_text`
+        * :py:meth:`pathlib.Path.readlink`
+
+        * :py:meth:`pathlib.Path.mkdir` - we recommend :py:meth:`ubelt.Path.ensuredir` instead.
+
+        * :py:meth:`pathlib.Path.chmod`
+        * :py:meth:`pathlib.Path.lchmod`
+
+        * :py:meth:`pathlib.Path.unlink`
+        * :py:meth:`pathlib.Path.rmdir`
+
+        * :py:meth:`pathlib.Path.rename`
+        * :py:meth:`pathlib.Path.replace`
+
+        * :py:meth:`pathlib.Path.symlink_to`
+        * :py:meth:`pathlib.Path.hardlink_to`
+        * :py:meth:`pathlib.Path.link_to` - deprecated
+
+        * :py:meth:`pathlib.Path.exists`
+        * :py:meth:`pathlib.Path.is_dir`
+        * :py:meth:`pathlib.Path.is_file`
+        * :py:meth:`pathlib.Path.is_mount`
+        * :py:meth:`pathlib.Path.is_symlink`
+        * :py:meth:`pathlib.Path.is_block_device`
+        * :py:meth:`pathlib.Path.is_char_device`
+        * :py:meth:`pathlib.Path.is_fifo`
+        * :py:meth:`pathlib.Path.is_socket`
+
+        * :py:meth:`pathlib.Path.expanduser` - we recommend :py:meth:`ubelt.Path.expand` instead.
+
+        * :py:meth:`pathlib.PurePath.as_posix`
+        * :py:meth:`pathlib.PurePath.as_uri`
+
+        * :py:meth:`pathlib.PurePath.with_name` - we recommend :py:meth:`ubelt.Path.augment` instead.
+        * :py:meth:`pathlib.PurePath.with_stem`  - we recommend :py:meth:`ubelt.Path.augment` instead.
+        * :py:meth:`pathlib.PurePath.with_suffix` - we recommend :py:meth:`ubelt.Path.augment` instead.
+
+        * :py:meth:`pathlib.PurePath.relative_to`
+
+        * :py:meth:`pathlib.PurePath.joinpath`
+
+        * :py:meth:`pathlib.PurePath.is_relative_to`
+        * :py:meth:`pathlib.PurePath.is_absolute`
+        * :py:meth:`pathlib.PurePath.is_reserved`
+
+        * :py:meth:`pathlib.PurePath.match`
     """
     __slots__ = ()
 
     @classmethod
-    def appdir(cls, appname, *args, type='cache'):
+    def appdir(cls, appname=None, *args, type='cache'):
         """
-        Returns an operating system appropriate writable directory for an
-        application to be used for cache, configs, or data.
+        Returns a standard platform specific directory for an application to
+        use as cache, config, or data.
+
+        The default root location depends on the platform and is specified the
+        the following table:
+
+        TextArt:
+
+                   | POSIX            | Windows        | MacOSX
+            data   | $XDG_DATA_HOME   | %APPDATA%      | ~/Library/Application Support
+            config | $XDG_CONFIG_HOME | %APPDATA%      | ~/Library/Application Support
+            cache  | $XDG_CACHE_HOME  | %LOCALAPPDATA% | ~/Library/Caches
+
+
+            If an environment variable is not specified the defaults are:
+                APPDATA      = ~/AppData/Roaming
+                LOCALAPPDATA = ~/AppData/Local
+
+                XDG_DATA_HOME   = ~/.local/share
+                XDG_CACHE_HOME  = ~/.cache
+                XDG_CONFIG_HOME = ~/.config
 
         Args:
-            appname (str): the name of the application
-            *args[str] : optional subdirs
-            type (str): can be 'cache', 'config', or 'data'.
+            appname (str | None):
+                The name of the application.
+
+            *args : optional subdirs
+
+            type (str):
+                the type of data the expected to be stored in this application
+                directory. Valid options are 'cache', 'config', or 'data'.
 
         Returns:
-            Path: a new path object
+            Path: a new path object for the specified application directory.
+
+        SeeAlso:
+            This provides functionality similar to the
+            `appdirs <https://pypi.org/project/appdirs/>`_ -
+            and
+            `platformdirs <https://platformdirs.readthedocs.io/en/latest/api.html>`_ -
+            packages.
 
         Example:
             >>> # xdoctest: +IGNORE_WANT
@@ -446,6 +613,13 @@ class Path(_PathBase):
             >>> import pytest
             >>> with pytest.raises(KeyError):
             >>>     ub.Path.appdir('ubelt', type='other')
+
+        Example:
+            >>> # xdoctest: +IGNORE_WANT
+            >>> import ubelt as ub
+            >>> # Can now call appdir without any arguments
+            >>> print(ub.Path.appdir().shrinkuser())
+            ~/.cache
         """
         from ubelt import util_platform
         if type == 'cache':
@@ -456,7 +630,11 @@ class Path(_PathBase):
             base = util_platform.platform_data_dir()
         else:
             raise KeyError(type)
-        return cls(base, appname, *args)
+
+        if appname is None:
+            return cls(base, *args)
+        else:
+            return cls(base, appname, *args)
 
     def augment(self, prefix='', stemsuffix='', ext=None, stem=None, dpath=None,
                 tail='', relative=None, multidot=False, suffix=''):
@@ -503,9 +681,9 @@ class Path(_PathBase):
                 DEPRECAETD
 
         SeeAlso:
-            # Stdlib ways of augmenting
-            pathlib.Path.with_stem
-            pathlib.Path.with_suffix
+            :py:meth:`pathlib.Path.with_stem`
+            :py:meth:`pathlib.Path.with_name`
+            :py:meth:`pathlib.Path.with_suffix`
 
         Returns:
             Path: augmented path
@@ -516,6 +694,8 @@ class Path(_PathBase):
             THE INITIAL RELEASE OF Path.augment suffered from an unfortunate
             variable naming decision that conflicts with pathlib.Path
 
+            .. code:: python
+
             p = ub.Path('the.entire.fname.or.dname.is.the.name.exe')
             print(f'p     ={p}')
             print(f'p.name={p.name}')
@@ -661,11 +841,29 @@ class Path(_PathBase):
         self.mkdir(mode=mode, parents=True, exist_ok=True)
         return self
 
+    def mkdir(self, mode=511, parents=False, exist_ok=False):
+        """
+        Create a new directory at this given path.
+
+        Note:
+            The ubelt variant is the same, except it returns the path as well.
+
+        Args:
+            mode (int) : perms
+            parents (bool) : create parents
+            exist_ok (bool) : fail if exists
+
+        Returns:
+            Path: returns itself
+        """
+        super().mkdir(mode=mode, parents=parents, exist_ok=exist_ok)
+        return self
+
     def expand(self):
         """
         Expands user tilde and environment variables.
 
-        Concise alias of `Path(os.path.expandvars(self.expanduser()))`
+        Concise alias of ``Path(os.path.expandvars(self.expanduser()))``
 
         Returns:
             Path: path with expanded environment variables and tildes
@@ -731,7 +929,9 @@ class Path(_PathBase):
 
     def shrinkuser(self, home='~'):
         """
-        Inverse of :func:`os.path.expanduser`.
+        Shrinks your home dir by replacing it with a tilde.
+
+        This is the inverse of :func:`os.path.expanduser`.
 
         Args:
             home (str): symbol used to replace the home path.
@@ -761,7 +961,7 @@ class Path(_PathBase):
         Returns:
             Path: returns itself
 
-        Notes:
+        Note:
             The :func:`ubelt.util_io.touch` function currently has a slightly
             different implementation. This uses whatever the pathlib version
             is. This may change in the future.
@@ -774,7 +974,7 @@ class Path(_PathBase):
 
     def walk(self, topdown=True, onerror=None, followlinks=False):
         """
-        A variant of os.walk for pathlib
+        A variant of :func:`os.walk` for pathlib
 
         Args:
             topdown (bool):
@@ -946,63 +1146,342 @@ class Path(_PathBase):
         """
         return os.fspath(self).startswith(prefix, *args)
 
-    # TODO: add more shutil functionality
+    # More shutil functionality
     # This is discussed in https://peps.python.org/pep-0428/#filesystem-modification
-    if 0:
-        # Stub out potential new functionality
-        def copy(self, dst, follow_file_symlinks=True,
-                 follow_dir_symlinks=True,
-                 copy_bits='stats'):
-            """
-            Copy this file or directory to dst.
 
-            Args:
-                dst (str | PathLike):
-                    if `src` is a file and `dst` is a directory, copies this to `dst / src.name`
-                    if `src` is a file and `dst` does not exist, copies this to `dst`
+    def _request_copy_function(self, follow_file_symlinks=True,
+                               follow_dir_symlinks=True, meta='stats'):
+        """
+        Get a copy_function based on specified capabilities
+        """
+        import shutil
+        from functools import partial
+        if meta is None:
+            copy_function = partial(shutil.copyfile, follow_symlinks=follow_file_symlinks)
+        elif meta == 'stats':
+            copy_function = partial(shutil.copy2, follow_symlinks=follow_file_symlinks)
+        elif meta == 'mode':
+            copy_function = partial(shutil.copy, follow_symlinks=follow_file_symlinks)
+        else:
+            raise KeyError(meta)
+        return copy_function
 
-                    todo if `src` is a directory and `dst` is a directory, copies this to `dst / src.name`
-                    todo if `src` is a directory and `dst` does not exist, copies this to `dst`
+    def copy(self, dst, follow_file_symlinks=False, follow_dir_symlinks=False,
+             meta='stats', overwrite=False):
+        """
+        Copy this file or directory to dst.
 
-                follow_file_symlinks (bool):
-                    If True and src is a link, the link will be resolved before
-                    it is copied (i.e. the data is duplicated), otherwise just
-                    the link itself will be copied.
+        By default files are never overwritten and symlinks are copied as-is.
 
-                follow_dir_symlinks (bool):
-                    if True when src is a directory and contains symlinks to
-                    other directories, the contents of the linked data are
-                    copied, otherwise when False only the link itself is
-                    copied.
 
-                copy_bits (str | None):
-                    Indicates what metadata bits to copy. This can be 'stats'
-                    which tries to copy all metadata (i.e. like shutil.copy2),
-                    'mode' which copies just the permission bits (i.e. like
-                    shutil.copy), or None, which ignores all metadata (i.e.
-                    like shutil.copyfile).
+        At a basic level (i.e. ignoring symlinks) for each path argument
+        (``src`` and ``dst``) these can either be files, directories, or not
+        exist. Given these three states, the following table summarizes how
+        this function copies this path to its destination.
 
-            """
-            import shutil
-            from functools import partial
-            if copy_bits is None:
-                copyfunction = partial(shutil.copyfile, follow_symlinks=follow_file_symlinks)
-            elif copy_bits == 'stats':
-                copyfunction = partial(shutil.copy2, follow_symlinks=follow_file_symlinks)
-            elif copy_bits == 'mode':
-                copyfunction = partial(shutil.copy, follow_symlinks=follow_file_symlinks)
+        TextArt:
+
+            +----------+------------------------+------------------------+------------+
+            | dst      | dir                    | file                   | no-exist   |
+            +----------+                        |                        |            |
+            | src      |                        |                        |            |
+            +==========+========================+========================+============+
+            | dir      | error-or-overwrite-dst | error                  | dst        |
+            +----------+------------------------+------------------------+------------+
+            | file     | dst / src.name         | error-or-overwrite-dst | dst        |
+            +----------+------------------------+------------------------+------------+
+            | no-exist | error                  | error                  | error      |
+            +----------+------------------------+------------------------+------------+
+
+        In general, the contents of src will be the contents of dst, except for
+        the one case where a file is copied into an existing directory. In this
+        case the name is used to construct a fully qualified destination.
+
+        Ignore:
+            # Enumerate cases
+            rows = [
+                {'src': 'no-exist', 'dst': 'no-exist', 'result': 'error'},
+                {'src': 'no-exist', 'dst': 'file',     'result': 'error'},
+                {'src': 'no-exist', 'dst': 'dir',      'result': 'error'},
+
+                {'src': 'file', 'dst': 'no-exist', 'result': 'dst'},
+                {'src': 'file', 'dst': 'dir',      'result': 'dst / src.name'},
+                {'src': 'file', 'dst': 'file',     'result': 'error-or-overwrite-dst'},
+
+                {'src': 'dir', 'dst': 'no-exist', 'result': 'dst'},
+                {'src': 'dir', 'dst': 'dir',      'result': 'error-or-overwrite-dst'},
+                {'src': 'dir', 'dst': 'file',     'result': 'error'},
+            ]
+            import pandas as pd
+            df = pd.DataFrame(rows)
+            piv = df.pivot(['src'], ['dst'], 'result')
+            print(piv.to_markdown(tablefmt="presto"))
+            print(piv.to_markdown(tablefmt="pretty", index=True))
+            print(piv.to_markdown(tablefmt="grid", index=True))
+
+        Args:
+            dst (str | PathLike):
+                if `src` is a file and `dst` does not exist, copies this to `dst`
+                if `src` is a file and `dst` is a directory, copies this to `dst / src.name`
+
+                if `src` is a directory and `dst` does not exist, copies this to `dst`
+                if `src` is a directory and `dst` is a directory, errors unless
+                overwrite is True, in which case, copies this to `dst` and
+                overwrites anything conflicting path.
+
+            follow_file_symlinks (bool):
+                If True and src is a link, the link will be resolved before
+                it is copied (i.e. the data is duplicated), otherwise just
+                the link itself will be copied.
+
+            follow_dir_symlinks (bool):
+                if True when src is a directory and contains symlinks to
+                other directories, the contents of the linked data are
+                copied, otherwise when False only the link itself is
+                copied.
+
+            meta (str | None):
+                Indicates what metadata bits to copy. This can be 'stats' which
+                tries to copy all metadata (i.e. like :py:func:`shutil.copy2`),
+                'mode' which copies just the permission bits (i.e. like
+                :py:func:`shutil.copy`), or None, which ignores all metadata
+                (i.e.  like :py:func:`shutil.copyfile`).
+
+            overwrite (bool):
+                if False, and target file exists, this will raise an error,
+                otherwise the file will be overwritten.
+
+        Returns:
+            Path: where the path was actually copied to
+
+        Note:
+            This is implemented with a combination of :func:`shutil.copy`,
+            :func:`shutil.copy2`, and :func:`shutil.copytree`, but the The
+            defaults and behavior here are noticably different (and hopefully
+            safer and more intuitive).
+
+        Example:
+            >>> import ubelt as ub
+            >>> root = ub.Path.appdir('ubelt', 'tests', 'path', 'copy').delete().ensuredir()
+            >>> paths = {}
+            >>> dpath = (root / 'orig').ensuredir()
+            >>> clone0 = (root / 'dst_is_explicit').ensuredir()
+            >>> clone1 = (root / 'dst_is_parent').ensuredir()
+            >>> paths['fpath'] = (dpath / 'file0.txt').touch()
+            >>> paths['empty_dpath'] = (dpath / 'empty_dpath').ensuredir()
+            >>> paths['nested_dpath'] = (dpath / 'nested_dpath').ensuredir()
+            >>> (dpath / 'nested_dpath/d0').ensuredir()
+            >>> (dpath / 'nested_dpath/d0/f1.txt').touch()
+            >>> (dpath / 'nested_dpath/d0/f2.txt').touch()
+            >>> print('paths = {}'.format(ub.repr2(paths, nl=1)))
+            >>> assert all(p.exists() for p in paths.values())
+            >>> paths['fpath'].copy(clone0 / 'file0.txt')
+            >>> paths['fpath'].copy(clone1)
+            >>> paths['empty_dpath'].copy(clone0 / 'empty_dpath')
+            >>> paths['empty_dpath'].copy((clone1 / 'empty_dpath_alt').ensuredir(), overwrite=True)
+            >>> paths['nested_dpath'].copy(clone0 / 'nested_dpath')
+            >>> paths['nested_dpath'].copy((clone1 / 'nested_dpath_alt').ensuredir(), overwrite=True)
+
+        Ignore:
+            import xdev
+            xdev.tree_repr(dpath)
+            xdev.tree_repr(clone0, max_files=10)
+            xdev.tree_repr(clone1, max_files=10)
+        """
+        warnings.warn('The ub.Path.copy function is experimental and may change, '
+                      'in corner cases. Primary cases seem stable.')
+        import shutil
+        copy_function = self._request_copy_function(
+            follow_file_symlinks=follow_file_symlinks,
+            follow_dir_symlinks=follow_dir_symlinks, meta=meta)
+        if self.is_dir():
+            if sys.version_info[0:2] < (3, 8):  # nocover
+                copytree = _compat_copytree
             else:
-                raise KeyError(copy_bits)
+                copytree = shutil.copytree
+            dst = copytree(
+                self, dst, copy_function=copy_function,
+                symlinks=not follow_dir_symlinks, dirs_exist_ok=overwrite)
+        elif self.is_file():
+            if not overwrite:
+                dst = Path(dst)
+                if dst.is_dir():
+                    real_dst = dst / self.name
+                else:
+                    real_dst = dst
+                if real_dst.exists():
+                    raise FileExistsError('Cannot overwrite existing file unless overwrite=True')
+            dst = copy_function(self, dst)
+        else:
+            raise Exception
+        return Path(dst)
 
-            if self.is_dir():
-                shutil.copytree(
-                    self, dst, copyfunction=copyfunction,
-                    symlinks=not follow_dir_symlinks)
-            elif self.is_file():
-                dst = copyfunction(self, dst)
-            else:
-                raise Exception
+    def move(self, dst, follow_file_symlinks=False, follow_dir_symlinks=False,
+             meta='stats'):
+        """
+        Move a file from one location to another, or recursively move a
+        directory from one location to another.
 
-        def move(self, dst):
-            import shutil
-            shutil.move(self, dst)
+        This method will refuse to overwrite anything, and there is currently
+        no overwrite option for technical reasons. This may change in the
+        future.
+
+        Args:
+            dst (str | PathLike):
+                A non-existing path where this file will be moved.
+
+            follow_file_symlinks (bool):
+                If True and src is a link, the link will be resolved before
+                it is copied (i.e. the data is duplicated), otherwise just
+                the link itself will be copied.
+
+            follow_dir_symlinks (bool):
+                if True when src is a directory and contains symlinks to
+                other directories, the contents of the linked data are
+                copied, otherwise when False only the link itself is
+                copied.
+
+            meta (str | None):
+                Indicates what metadata bits to copy. This can be 'stats' which
+                tries to copy all metadata (i.e. like shutil.copy2), 'mode'
+                which copies just the permission bits (i.e. like shutil.copy),
+                or None, which ignores all metadata (i.e.  like
+                shutil.copyfile).
+
+        Note:
+            This method will refuse to overwrite anything.
+
+            This is implemented via :func:`shutil.move`, which depends heavily
+            on :func:`os.rename` semantics. For this reason, this function
+            error if it would overwrite any data. If you want an overwriting
+            variant of move we recommend you either either copy the data, and
+            then delete the original (potentially inefficient), or use
+            :func:`shutil.move` directly if you know how :func:`os.rename`
+            works on your system.
+
+        Returns:
+            Path: where the path was actually moved to
+
+        Example:
+            >>> import ubelt as ub
+            >>> dpath = ub.Path.appdir('ubelt', 'tests', 'path', 'move').delete().ensuredir()
+            >>> paths = {}
+            >>> paths['dpath0'] = (dpath / 'dpath0').ensuredir()
+            >>> paths['dpath00'] = (dpath / 'dpath0' / 'sub0').ensuredir()
+            >>> paths['fpath000'] = (dpath / 'dpath0' / 'sub0' / 'f0.txt').touch()
+            >>> paths['fpath001'] = (dpath / 'dpath0' / 'sub0' / 'f1.txt').touch()
+            >>> paths['dpath01'] = (dpath / 'dpath0' / 'sub1').ensuredir()
+            >>> print('paths = {}'.format(ub.repr2(paths, nl=1)))
+            >>> assert all(p.exists() for p in paths.values())
+            >>> # xdev.tree_repr(dpath, max_files=10)
+            >>> paths['dpath0'].move(dpath / 'dpath1')
+            >>> # xdev.tree_repr(dpath, max_files=10)
+
+        Ignore:
+            import xdev
+            xdev.tree_repr(dpath)
+        """
+        warnings.warn('The ub.Path.move function is experimental and may change! '
+                      'Do not rely on this behavior yet!')
+
+        # Behave more like POSIX move to avoid potential confusing behavior
+        if exists(dst):
+            raise FileExistsError(
+                'Moves are only allowed to locations that dont exist')
+        # if os.path.isdir(dst):
+        #     with os.scandir(dst) as itr:
+        #         is_empty = next(itr, None) is None
+        #     if not is_empty:
+        #         raise IOError(f'Cannot move {self!r} to {dst!r}. '
+        #                       'Directory not empty')
+
+        import shutil
+        copy_function = self._request_copy_function(
+            follow_file_symlinks=follow_file_symlinks,
+            follow_dir_symlinks=follow_dir_symlinks, meta=meta)
+        real_dst = shutil.move(self, dst, copy_function=copy_function)
+        return Path(real_dst)
+
+if sys.version_info[0:2] < (3, 8):  # nocover
+
+    # Vendor in a nearly modern copytree for Python 3.6 and 3.7
+    def _compat_copytree(src, dst, symlinks=False, ignore=None,
+                         copy_function=None, ignore_dangling_symlinks=False,
+                         dirs_exist_ok=False):
+        """
+        A vendored shutil.copytree for older pythons based on the 3.10
+        implementation
+        """
+        # import stat
+        from shutil import Error, copystat, copy2, copy
+        with os.scandir(src) as itr:
+            entries = list(itr)
+
+        if ignore is not None:
+            ignored_names = ignore(os.fspath(src), [x.name for x in entries])
+        else:
+            ignored_names = set()
+
+        os.makedirs(dst, exist_ok=dirs_exist_ok)
+        errors = []
+        use_srcentry = copy_function is copy2 or copy_function is copy
+
+        for srcentry in entries:
+            if srcentry.name in ignored_names:
+                continue
+            srcname = os.path.join(src, srcentry.name)
+            dstname = os.path.join(dst, srcentry.name)
+            srcobj = srcentry if use_srcentry else srcname
+            try:
+                is_symlink = srcentry.is_symlink()
+                if is_symlink and os.name == 'nt':
+                    # Special check for directory junctions, which appear as
+                    # symlinks but we want to recurse.
+                    # Not available on 3.6, use our impl instead
+                    # lstat = srcentry.stat(follow_symlinks=False)
+                    # if lstat.st_reparse_tag == stat.IO_REPARSE_TAG_MOUNT_POINT:
+                    #   is_symlink = False
+                    from ubelt._win32_links import _win32_is_junction
+                    if _win32_is_junction(srcentry):
+                        is_symlink = False
+                if is_symlink:
+                    linkto = os.readlink(srcname)
+                    if symlinks:
+                        # We can't just leave it to `copy_function` because legacy
+                        # code with a custom `copy_function` may rely on copytree
+                        # doing the right thing.
+                        os.symlink(linkto, dstname)
+                        copystat(srcobj, dstname, follow_symlinks=not symlinks)
+                    else:
+                        # ignore dangling symlink if the flag is on
+                        if not os.path.exists(linkto) and ignore_dangling_symlinks:
+                            continue
+                        # otherwise let the copy occur. copy2 will raise an error
+                        if srcentry.is_dir():
+                            _compat_copytree(srcobj, dstname, symlinks, ignore,
+                                             copy_function,
+                                             dirs_exist_ok=dirs_exist_ok)
+                        else:
+                            copy_function(srcobj, dstname)
+                elif srcentry.is_dir():
+                    _compat_copytree(srcobj, dstname, symlinks, ignore,
+                                     copy_function,
+                                     dirs_exist_ok=dirs_exist_ok)
+                else:
+                    # Will raise a SpecialFileError for unsupported file types
+                    copy_function(srcobj, dstname)
+            # catch the Error from the recursive copytree so that we can
+            # continue with other files
+            except Error as err:
+                errors.extend(err.args[0])
+            except OSError as why:
+                errors.append((srcname, dstname, str(why)))
+        try:
+            copystat(src, dst)
+        except OSError as why:
+            # Copying file access times may fail on Windows
+            if getattr(why, 'winerror', None) is None:
+                errors.append((src, dst, str(why)))
+        if errors:
+            raise Error(errors)
+        return dst
